"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkMajorVersion = exports.runPreRequisiteChecks = exports.loadPropertiesFile = void 0;
const node_fs_1 = require("node:fs");
const loadPropertiesFile = (path) => {
    const contents = (0, node_fs_1.readFileSync)(path, 'utf-8');
    return contents
        .split('\n')
        .filter(Boolean) // filter out blank lines
        .map((l) => l.split('='))
        .reduce((acc, value) => {
        acc[value[0]] = value.slice(1).join('=');
        return acc;
    }, {});
};
exports.loadPropertiesFile = loadPropertiesFile;
const handleCheckStatus = (check, success, error) => {
    if (success) {
        console.log(`Pre-requisite check successful: ${check.name}`);
    }
    else {
        console.error(`Pre-requisite check failed: ${check.name}.`, error === null || error === void 0 ? void 0 : error.message);
    }
    if (!success) {
        process.exit(1);
    }
};
const runPreRequisiteChecks = (data, checks) => checks.every((check) => {
    let success = false;
    try {
        success = check.handler(data);
    }
    catch (e) {
        success = false;
        handleCheckStatus(check, success, e);
    }
    handleCheckStatus(check, success);
    return success;
});
exports.runPreRequisiteChecks = runPreRequisiteChecks;
const onlyDigits = (input) => input.replace(/\D/g, '');
const checkMajorVersion = (required, actual) => {
    const [major1] = required.split('.');
    const [major2] = actual.split('.');
    return onlyDigits(major1) === onlyDigits(major2);
};
exports.checkMajorVersion = checkMajorVersion;
//# sourceMappingURL=utils.js.map